==> ksrnd-0.93.tar.gz: ksrnd-0.93/ksrnd/main.cpp <==
/*
    KSrnd
    
    A control panel for the miroMEDIA Surround Dolby Pro Logic decoder.

    Copyright (C) 1998 Oliver Gantz (o.gantz@tu-bs.de)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    ----
    3D-Phonic(R) is a registered trademark of VICTOR COMPANY OF JAPAN, LIMITED.
    DOLBY and PRO LOGIC are trademarks of Dolby Laboratories Licensing Corporation.
    miro(R) is a registered trademark of miro Computer Products AG.
*/

#include "ksrnd.h"
#include <kapp.h>

KApplication * mykapp;
KSrnd * ksrnd;


int main(int argc, char *argv[])
{
	int ret;

	mykapp = new KApplication(argc, argv, "ksrnd");

	ksrnd = new KSrnd();

	if (mykapp->isRestored() && KTopLevelWidget::canBeRestored(1))
		ksrnd->restore(1);

	mykapp->setMainWidget(ksrnd);
	mykapp->setTopWidget(ksrnd);

	ret = mykapp->exec();

	delete ksrnd;
	delete mykapp;

	return ret;
}

==> ksrnd-0.97.tar.gz: ksrnd-0.97/ksrnd/main.cpp <==
/*
    KSrnd
    
    A control panel for the miroMEDIA Surround Dolby Pro Logic decoder.

    Copyright (C) 1998-2000 Oliver Gantz (o.gantz@tu-bs.de)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    ----
    3D-Phonic(R) is a registered trademark of VICTOR COMPANY OF JAPAN, LIMITED.
    DOLBY and PRO LOGIC are trademarks of Dolby Laboratories Licensing Corporation.
    miro(R) is a registered trademark of miro Computer Products AG.
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif 

#include <string.h>
#include <unistd.h>
#include <stdio.h>

#include <kapp.h>

#include "ksrnd.h"


KApplication * mykapp;
KSrnd * ksrnd;


void print_version (void)
{
	fprintf(stderr, "ksrnd %s\n", VERSION);
}


void print_help (void)
{
	fprintf(stderr, "Usage: ksrnd [-help] [-version] [generic Qt or KDE arguments]\n");
}


int main(int argc, char *argv[])
{
	int ret, i;
	
	for (i=1; i < argc; i++) {
		if (strcmp(argv[i], "-help") == 0) {
			print_help();
			exit(1);
		}
		else if (strcmp(argv[i], "-version") == 0) {
			print_version();
			exit(1);
		}
	}

	mykapp = new KApplication( argc, argv, "ksrnd" );

	ksrnd = new KSrnd();

	if (mykapp->isRestored() && KTopLevelWidget::canBeRestored( 1 ))
		ksrnd->restore( 1 );

	mykapp->setMainWidget( ksrnd );

	if (ksrnd->startVisible)
		ksrnd->show();
	else
		ksrnd->toggleVisible();

	ret = mykapp->exec();

	delete ksrnd;
	delete mykapp;

	return ret;
}
